pub enum FeatureContract {
Show 13 variants
AccountWithLongValidate(CairoVersion),
AccountWithoutValidations(CairoVersion),
EmptyAccount(RunnableCairo1),
ERC20(CairoVersion),
Empty(CairoVersion),
FaultyAccount(CairoVersion),
LegacyTestContract,
SecurityTests,
TestContract(CairoVersion),
CairoStepsTestContract,
SierraExecutionInfoV1Contract(RunnableCairo1),
MetaTx(RunnableCairo1),
MockStakingContract(RunnableCairo1),
}Expand description
Enum representing all feature contracts. The contracts that are implemented in both Cairo versions include a version field.
Variants
AccountWithLongValidate(CairoVersion)
AccountWithoutValidations(CairoVersion)
EmptyAccount(RunnableCairo1)
ERC20(CairoVersion)
Empty(CairoVersion)
FaultyAccount(CairoVersion)
LegacyTestContract
SecurityTests
TestContract(CairoVersion)
CairoStepsTestContract
SierraExecutionInfoV1Contract(RunnableCairo1)
MetaTx(RunnableCairo1)
MockStakingContract(RunnableCairo1)
Implementations
Sourceimpl FeatureContract
impl FeatureContract
pub fn cairo_version(&self) -> CairoVersion
pub fn set_cairo_version(&mut self, version: CairoVersion)
pub fn get_class_hash(&self) -> ClassHash
Sourcepub fn get_compiled_class_hashes_constants(&self) -> (Expect, Expect)
pub fn get_compiled_class_hashes_constants(&self) -> (Expect, Expect)
as consts Expect strings.
pub fn get_compiled_class_hash( &self, hash_version: &HashVersion, ) -> CompiledClassHash
Sourcepub fn instance_address(integer_base: u32, instance_id: u32) -> ContractAddress
pub fn instance_address(integer_base: u32, instance_id: u32) -> ContractAddress
Returns the address of the instance with the given instance ID.
Sourcepub fn get_instance_address(&self, instance_id: u16) -> ContractAddress
pub fn get_instance_address(&self, instance_id: u16) -> ContractAddress
Returns the address of the instance with the given instance ID.
pub fn get_raw_sierra(&self) -> Option<String>
pub fn get_sierra(&self) -> SierraContractClass
pub fn safe_get_sierra(&self) -> Option<SierraContractClass>
pub fn get_sierra_version(&self) -> SierraVersion
pub fn get_raw_class(&self) -> String
Sourcepub fn fixed_version(&self) -> CairoVersionString
pub fn fixed_version(&self) -> CairoVersionString
Some Cairo1 contracts are designed to test behavior of code compiled with a specific (old) compiler version. Returns the compiler version used to compile the contract. Panics if called on a Cairo0 contract.
Sourcepub fn get_integer_base(self) -> u32
pub fn get_integer_base(self) -> u32
Unique integer representing each unique contract. Used to derive “class hash”, “address” and “compiled class hash”.
pub fn get_non_erc20_base_name(&self) -> &str
pub fn get_source_path(&self) -> String
pub fn get_sierra_path(&self) -> String
pub fn get_compiled_path(&self) -> String
Sourcepub fn compile(&self) -> CompilationArtifacts
pub fn compile(&self) -> CompilationArtifacts
Compiles the feature contract and returns the compiled contract as a byte vector. Panics if the contract is ERC20, as ERC20 contract recompilation is not supported.
pub fn all_contracts() -> impl Iterator<Item = Self>
pub fn all_feature_contracts() -> impl Iterator<Item = Self>
pub fn all_cairo1_casm_feature_contracts() -> impl Iterator<Item = Self>
pub fn all_cairo1_casm_compiler_versions() -> HashSet<CairoVersionString>